@@ -1267,7 +1267,6 @@ end
 
 # TODO: MultiFloat-Int arithmetic operators.
 
-
 ########################################################### ARITHMETIC OVERLOADS
 
 
@@ -1295,6 +1294,12 @@ end
 @inline Base.inv(x::_MFV{M,T,N}) where {M,T,N} = one(_MFV{M,T,N}) / x
 
 
+@inline Base.:^(x::_MF{T,N}, p::Integer) where {T,N} =
+    signbit(p) ? Base.power_by_squaring(inv(x), -p) : Base.power_by_squaring(x, p)
+@inline Base.:^(x::_MFV{M,T,N}, p::Integer) where {M,T,N} =
+    signbit(p) ? Base.power_by_squaring(inv(x), -p) : Base.power_by_squaring(x, p)
+
+
 @inline Base.sum(x::_MFV{M,T,N}) where {M,T,N} =
     +(ntuple(i -> x[i], Val{M}())...)
 
